==> haskell-djinn-lib-0.0.1.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-lib
version:              0.0.1.3
visibility:           public
id:                   djinn-lib-0.0.1.3-DOryDew7bfyEoBorDVeV0h
key:                  djinn-lib-0.0.1.3-DOryDew7bfyEoBorDVeV0h
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  86af6e323b4ffe3c6a0dd0f14be48dae
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-9.0.1/site-local/djinn-lib-0.0.1.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/djinn-lib-0.0.1.3
hs-libraries:         HSdjinn-lib-0.0.1.3-DOryDew7bfyEoBorDVeV0h
depends:
    base-4.15.0.0 containers-0.6.4.1 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-lib-0.0.1.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-lib
version:              0.0.1.4
visibility:           public
id:                   djinn-lib-0.0.1.4-GkKPg8UvR821F4hI2AaIeL
key:                  djinn-lib-0.0.1.4-GkKPg8UvR821F4hI2AaIeL
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  d590ad5a402f996dad259c1f6af914f1
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-9.0.2/site-local/djinn-lib-0.0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/djinn-lib-0.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/djinn-lib-0.0.1.4
hs-libraries:         HSdjinn-lib-0.0.1.4-GkKPg8UvR821F4hI2AaIeL
depends:
    base-4.15.1.0 containers-0.6.4.1 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
